<?php

$lang['page_title'] = 'Sitemap';

$lang['display_success'] = 'Information has been successfully updated.';
$lang['display_error'] = 'Error updating. Priority must be> = 0 and <= 1';

$lang['button_save'] = 'Save';
$lang['button_generate'] = 'Generating sitemap.xml';
$lang['label_module'] = 'Module';
$lang['label_changefreq'] = 'Changefreq';
$lang['label_priority'] = 'Priority';
$lang['label_base_page'] = 'Base page';

$lang['generate_success'] = 'Generation was successful!';
$lang['generate_error'] = 'Error generating!';

$lang['cache_life'] = 'Cache life';
$lang['base_properties'] = 'Base properties';
$lang['cache_life_input'] = 'Cache life, sec';



