$(document).ready(function () {
    $('#form_send').click(function () {
        $('#module_map').submit();
        return false;
    });
    $('.prepare-sitemap').click(function () {
        $(this).addClass('disabled');
        $('.prepare-sitemap-loader').show();
        $.post('/ajax/sitemap/sitemap_admin/action', {'method': 'prepare_sitemap'}, function (data) {
            $('.prepare-sitemap').removeClass('disabled');
            $('.prepare-sitemap-loader').hide();
            var obj = $.parseJSON(data);
            if (obj.status) {
                location.reload();
            }
        });

        return false;
    })
});

