<?php 

$lang['module_name'] = 'sitemap';
$lang['module_prop'] = 'Edit';

$lang['module_actions'] = array(
    // 'acl_action' => 'description'
    'view_sitemap' => 'View',
    'edit_sitemap' => 'Edit'
);

$lang['module_menu_items'] = array(
//    array('method in admin controller', 'title in menu', 'path to the image. empty - default image', 'acl_action')
    array('manage', $lang['module_prop'], '', 'view_sitemap')
);
