
.prepare-sitemap-loader{
    float: right;
    margin: 5px;
    display: none;
}
.compare-info {
    border-collapse: collapse;
    width: 100%;
    border-top: 1px solid #DDDDDD;
    border-left: 1px solid #DDDDDD;
    margin-bottom: 20px;
}
.compare-info thead td, .compare-info thead tr td:first-child {
    color: #000000;
    font-size: 14px;
    font-weight: bold;
    background: #F7F7F7;
    /*text-align: left;*/
}
.compare-info tr td:first-child {
    color: #000000;
    font-weight: bold;
    /*text-align: right;*/
}
.compare-info td {
    padding: 7px;
    width: 20%;
    color: #4D4D4D;
    text-align: center;
    vertical-align: top;
    border-right: 1px solid #DDDDDD;
    border-bottom: 1px solid #DDDDDD;
}
.compare-info .name a {
    font-weight: bold;
}
.compare-info .price-old {
    font-weight: bold;
    color: #F00;
    text-decoration: line-through;
}
.compare-info .price-new {
    font-weight: bold;
}
.additional-info{
    margin-top: 20px;
    width: 100%;
    float: left;
}
.additional-info h2{
    font-size: 18px;
    color: red;
    text-decoration: underline;
}
.additional-info ul{
    width: 100%;
    float: left;
}
.additional-info ul li{
    list-style: square;
    margin-left: 30px;
    width: 100%;
    float: left;
}