<?php

$lang['page_title'] = 'Sitemap';

$lang['display_success'] = 'Інформацію успішно оновлено.';
$lang['display_error'] = 'Помилка оновлення. Пріоритет має бути >= 0 і <= 1 ';

$lang['button_save'] = 'Зберегти';
$lang['button_generate'] = 'Генерація sitemap.xml';
$lang['label_module'] = 'Модуль';
$lang['label_changefreq'] = 'Частота оновлень';
$lang['label_priority'] = 'Пріоритет';
$lang['label_base_page'] = 'Базова сторінка';

$lang['generate_success'] = 'Генерація пройшла успішно!';
$lang['generate_error'] = 'Помилка при генерації!';

$lang['cache_life'] = 'Частота генерації карти сайту';
$lang['base_properties'] = 'Базові налаштування';
$lang['cache_life_input'] = 'Частота генерації, сек';
