CREATE TABLE IF NOT EXISTS `sitemap_config` (
  `id_sitemap_config` int(11) NOT NULL AUTO_INCREMENT,
  `module_name` varchar(128) CHARACTER SET utf8 NOT NULL,
  `changefreq` varchar(128) CHARACTER SET utf8 NOT NULL DEFAULT 'daily',
  `priority` varchar(128) CHARACTER SET utf8 NOT NULL DEFAULT '0.5',
  `basepage` int(11) NOT NULL,
   PRIMARY KEY (`id_sitemap_config`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE IF NOT EXISTS `sitemap_error_link` (
               `id_sitemap_error_link` int(11) NOT NULL AUTO_INCREMENT,
                `link` varchar(255) CHARACTER SET utf8 NOT NULL,
                PRIMARY KEY (`id_sitemap_error_link`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `sitemap_image` (
               `id_sitemap_image` int(11) NOT NULL AUTO_INCREMENT,
                `href` varchar(255) CHARACTER SET utf8 NOT NULL,
                `path` varchar(255) CHARACTER SET utf8 NOT NULL,
                PRIMARY KEY (`id_sitemap_image`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;