<?php

$lang['page_title'] = 'Sitemap';

$lang['display_success'] = 'Информация успешно обновлена.';
$lang['display_error'] = 'Ошибка при обновлении. Приоритет должен быть >= 0 и <= 1 ';

$lang['button_save'] = 'Сохранить';
$lang['button_generate'] = 'Генерация sitemap.xml';
$lang['label_module'] = 'Модуль';
$lang['label_changefreq'] = 'Частота обновлений';
$lang['label_priority'] = 'Приоритет';
$lang['label_base_page'] = 'Базовая страница';

$lang['generate_success'] = 'Генерация прошла успешно!';
$lang['generate_error'] = 'Ошибка при генерации!';

$lang['cache_life'] = 'Частота генерации карты сайта';
$lang['base_properties'] = 'Базовые настройки';
$lang['cache_life_input'] = 'Частота генерации, сек';
